<?php

    namespace Modules\KonfirmasiBank\Http\Controllers;

    use Illuminate\Contracts\Support\Renderable;
    use Illuminate\Http\Request;
    use Illuminate\Routing\Controller;
    use Illuminate\Support\Facades\Auth;
    use Modules\KonfirmasiBank\DataTables\ViewAccountDataTable;
    use Modules\KonfirmasiBank\Entities\ViewAccount;
    use Modules\KonfirmasiBank\Entities\LimitReference;
    use Modules\KonfirmasiBank\Entities\Fasilitas;
    use Dompdf\Dompdf;
    use Carbon\Carbon;
    use Illuminate\Support\Facades\View;
    use Illuminate\Support\Facades\Validator;
    use Modules\KonfirmasiBank\Http\Requests\Fasilitas\StoreFasilitasRequest;
    class KonfirmasiBankController extends Controller
    {
        public $user;

        public function __construct()
        {
            $this->middleware(function ($request, $next) {
                $this->user = Auth::guard('web')->user();
                return $next($request);
            });

            addVendor('chained-select');

        }
        public function index(Request $request)
        {
        $data = [];
        // Tanggal awal
        // Contoh tanggal saat ini
        $today = Carbon::now();

        // Menambahkan 1 tahun ke tanggal saat ini
        $currentYear = $today->format("Y");

        // Menambahkan 5 tahun ke tanggal saat ini
        $pastYear = $today->subYear(3)->format('Y');

        $data['currentYear'] = $currentYear;
        $data['pastYear'] = $pastYear;
        // dd($data);

        return view('konfirmasibank::pages.index',compact('data'));
        }

        public function getData(Request $request)
        {
        $data = [];
        $Account = new ViewAccount;

        $Accounts = $Account->getSearchAccount($request->cif, $request->kodecabang,$request->periode)->get();
        foreach ($Accounts as $key => $account) {
        $data[$key]['ACCOUNT_NUMBER'] = $account->ACCOUNT_NUMBER;
        $data[$key]['COMPANY_NAME'] = $account->COMPANY_NAME;
        $data[$key]['SHORT_TITLE'] = $account->SHORT_TITLE;
        $data[$key]['WORKING_BALANCE'] = $account->WORKING_BALANCE;
        $data[$key]['PRODUCT'] = $account->PRODUCT;
        $data[$key]['CURRENCY'] = $account->CURRENCY;
        $data[$key]['MATURITY_DATE'] = $account->MATURITY_DATE ?? '-';
        }
        return json_encode($data);
        }


          /*
          ----- export pdf -----
          */
          public function export(Request $request) {
             if (is_null($this->user) || !$this->user->can('konfirmasibank.report')) {
                abort(403, 'Sorry !! You are Unauthorized to view any master data !');
             }

            $account = explode("," , $request['acc_no']);

            $ViewAccount = new ViewAccount;
            $data = [];
            $DataAccounts = [];
            $DataPinjaman = [];
            $DataLimit = [];
            $ListAccount = $ViewAccount->getAccount($request['cus_no'],$account,$request['kode_cabang'],$request['periode']);

            foreach ($ListAccount as $key1 => $account) {
                   $DataAccounts[$key1]['ACCOUNT_NUMBER'] = $account->ACCOUNT_NUMBER;
                   $DataAccounts[$key1]['CUSTOMER_NO'] = $account->CUSTOMER_NO;
                   $DataAccounts[$key1]['CURRENCY'] = $account->CURRENCY;
                   $DataAccounts[$key1]['PRODUCT'] = $account->PRODUCT;
                   $DataAccounts[$key1]['COMPANY_NAME'] = $account->COMPANY_NAME;
                   $DataAccounts[$key1]['WORKING_BALANCE'] = $account->WORKING_BALANCE;
                   $DataAccounts[$key1]['BATCH_DATE'] = $account->BATCH_DATE;
                   $DataAccounts[$key1]['MATURITY_DATE'] = $account->MATURITY_DATE;
                   $ListBunga =$ViewAccount->getInterest($account->ARRANGEMENT_ID);
                   $ListTenor =$ViewAccount->getTerm($account->ARRANGEMENT_ID);
                 foreach ($ListBunga as $bunga) {
                    if (strpos($bunga->ID ,$account->ARRANGEMENT_ID) !== false) {
                          $DataAccounts[$key1]['FIXED_RATE'] = $bunga->FIXED_RATE;

                    }
                 }
            }


            $ListPinjaman =$ViewAccount->getPinjaman($ListAccount[0]->CUSTOMER_NO);
            $pinjaman = [];
            foreach ($ListPinjaman as $key => $item) {
               $ListTenor =$ViewAccount->getTerm($item->ARRANGEMENT_ID);
               $ListBunga =$ViewAccount->getInterest($item->ARRANGEMENT_ID);
               $ListCategory =$ViewAccount->getCategory($item->CATEGORY);
               $pinjaman[$key]['CUSTOMER'] = $item->CUSTOMER;
               $pinjaman[$key]['SHORT_NAME'] = $item->SHORT_NAME;
               $pinjaman[$key]['STREET'] = $item->STREET;
               $pinjaman[$key]['ADDRESS'] = $item->ADDRESS;
               $pinjaman[$key]['COMPANY_NAME'] = $item->COMPANY_NAME;
               $pinjaman[$key]['CURRENCY'] = $item->CURRENCY;
               $pinjaman[$key]['PRODUCT_LINE'] = $item->PRODUCT_LINE;
               $pinjaman[$key]['PRODUCT'] = $item->PRODUCT;
               $pinjaman[$key]['WORKING_BALANCE'] = $item->WORKING_BALANCE;
               $pinjaman[$key]['BATCH_DATE'] = $item->OPENING_DATE;
               $pinjaman[$key]['MATURITY_DATE'] = $item->MATURITY_DATE;

                foreach ($ListBunga as $bunga) {
                    if (strpos($bunga->ID ,$item->ARRANGEMENT_ID) !== false) {
                        $pinjaman[$key]['FIXED_RATE'] = $bunga->FIXED_RATE;
                    }
                }
                foreach ($ListTenor as $tenor) {
                    if (strpos($tenor->ID ,$item->ARRANGEMENT_ID) !== false) {
                        $pinjaman[$key]['TERM'] = $tenor->TERM;
                    }
                }
                foreach ($ListCategory as $category) {
                    if ($category->ID == $item->CATEGORY) {
                       $pinjaman[$key]['CATEGORY'] = $category->SHORT_NAME;
                    }
                }
            }

            $DataProducts = [];
            $ListLimits = $ViewAccount->getLimit($request['cus_no'],$request['periode']);

            $data['DataAccounts'] = $DataAccounts;
            $data['DataPinjaman'] = $pinjaman;
            $data['DataLimit'] = $ListLimits;

            $currentDate = Carbon::now();
           // $formattedDate = $currentDate->format('Y-m-d');

            $html = View::make('konfirmasibank::exportPdf', ['data' => $data])->render();

            $pdf = new Dompdf();
            $pdf->loadHtml($html);

             // Mengatur jenis kertas
             $pdf->setPaper('f4', 'landscape')->set_option('defaultFont', 'Arial');

             // Render HTML menjadi PDF
             $pdf->render();

             // Keluarkan file PDF ke browser
             $pdf->stream('"Konfirmasi_bank_"'.$ListPinjaman[0]->SHORT_NAME.'"'. $currentDate.'".pdf"');

          }

          public function addFasilitas(Request $request){

            if (is_null($this->user) || !$this->user->can('konfirmasibank.report')) {
                abort(403, 'Sorry !! You are Unauthorized to view any master data !');
            }

            $data = [];
            $fasilitas = Fasilitas::where('status', 1)->where('created_by',$this->user->id)->paginate(10);

            $limitReference =  LimitReference::all();
            $data['fasilitas'] = $fasilitas;
            $data['limitReference'] = $limitReference;

            return view('konfirmasibank::pages.index_fasilitas',compact('data'));

          }



          public function postFasilitas(Request $request){

            if (is_null($this->user) || !$this->user->can('konfirmasibank.create')) {
                abort(403, 'Sorry !! You are Unauthorized to create any konfirmasibank.create !');
            }

            $validated = $request->validate([
                'nomor_rekening' => 'required|string|max:10|unique:fasilitas,nomor_rekening',
                'jenis_fasilitas' => 'required|string',
                'saldo' => 'required|string',
                'start_date' => 'required|string',
                'due_date' => 'required|string',
                'jangka_waktu' => 'required|string',
                'fixed_rate' => 'required|string'
            ]);

            if ($validated) {
                try {
                // Create New User
                $fasilitas = new Fasilitas();
                $fasilitas->nomor_rekening = $request->nomor_rekening;
                $fasilitas->jenis_fasilitas = $request->jenis_fasilitas;
                $fasilitas->saldo = $request->saldo;
                $fasilitas->start_date = $request->start_date;
                $fasilitas->due_date = $request->due_date;
                $fasilitas->jangka_waktu = $request->jangka_waktu;
                $fasilitas->fixed_rate = $request->fixed_rate;
                $fasilitas->keterangan = $request->keterangan;

                $fasilitas->save();
                return redirect()->route('konfirmasibank.addFasilitas')->with('success', 'Data berhasil ditambahkan');

            } catch (Exception $e) {
                return json_encode([
                    'status' => 'error',
                    'message' => $e->getMessage()
                    ]);
                }
            }

            return false;

          }

          /**
          * Show the form for editing the specified resource.
          *
          * @param int $id
          *
          * @return Response
          */
          public function editFasilitas(Request $request)
          {

            if (is_null($this->user) || !$this->user->can('konfirmasibank.update')) {
                abort(403, 'Sorry !! You are Unauthorized to edit any role !');
            }

            $fasilitas = Fasilitas::find($request->id);

            return json_encode( $fasilitas);
          }

          /**
          * Update the specified resource in storage.
          *
          * @param Request $request
          * @param int $id
          *
          * @return Response
          */
          public function updateFasilitas(Request $request)
          {

            if (is_null($this->user) || !$this->user->can('konfirmasibank.update')) {
                abort(403, 'Sorry !! You are Unauthorized to edit any role !');
            }

            $today = Carbon::now();
            // Menambahkan 1 tahun ke tanggal saat ini
          //  $currentYear = $today->format("YYYY-MM-DD");

            // Validation Data\
             $validator = Validator::make($request->all(), [
                'nomor_rekening' => 'required|string|max:10|unique:fasilitas,nomor_rekening',
                'jenis_fasilitas' => 'required|string',
                'saldo' => 'required|string',
                'start_date' => 'required|string',
                'due_date' => 'required|string',
                'jangka_waktu' => 'required|string',
                'fixed_rate' => 'required|string'
                // Other validation rules
            ]);

            if ($validator->fails()) {
                return response()->json(['errors' => $validator->errors()], 422); // Return validation errors as JSON
            }


            if ($validator) {
                try {
                    $fasilitas = Fasilitas::findOrFail($request->id);
                    $fasilitas->nomor_rekening = $request->nomor_rekening;
                    $fasilitas->jenis_fasilitas = $request->jenis_fasilitas;
                    $fasilitas->saldo = $request->saldo;
                    $fasilitas->start_date = $request->start_date;
                    $fasilitas->due_date = $request->due_date;
                    $fasilitas->jangka_waktu = $request->jangka_waktu;
                    $fasilitas->fixed_rate = $request->fixed_rate;
                    $fasilitas->keterangan =  $request->keterangan;
                    $fasilitas->updated_at = $today;
                    $fasilitas->save();

                     echo json_encode(['status' => 'success', 'message' => ' fasilitas updated successfully.']);

                } catch (Exception $e) {
                    echo json_encode(['status' => 'error', 'message' => ' fasilitas updated failed.']);
                }

                return;

            }
            echo json_encode(['status' => 'error', 'message' => ' fasilitas updated failed.']);
        }


         /**
         * Remove the specified resource from storage.
         *
         * @param int $id
         *
         * @return Renderable
         */
        public function destroyFasilitas(Request $request)
        {
            if (is_null($this->user) || !$this->user->can('konfirmasibank.delete')) {
                abort(403, 'Sorry !! You are Unauthorized to delete any konfirmasibank module !');
            }

            $fasilitas = Fasilitas::findOrFail($request->id);

            try {
                $fasilitas->status = 0;
                $fasilitas->save();
                echo json_encode(['status' => 'success', 'message' => ' fasilitas deleted successfully.']);
            } catch (Exception $e) {
                echo json_encode(['status' => 'error', 'message' => ' fasilitas deleted failed.']);
            }
        }


    }